@@ -7,7 +7,7 @@ from mvapi.web.models.user import User
 
 @click.command('update-user')
 @click.option('--email', required=True, help='user email')
-@click.option('--is-admin', is_flag=True, help='make user an admin')
+@click.option('--is-admin/--not-admin', default=None, help='admin flag')
 @click.password_option(help='user password')
 def update_user(email, password, is_admin):
     """Update a user"""
@@ -21,7 +21,7 @@ def update_user(email, password, is_admin):
     if password:
         user.password = password
 
-    if is_admin:
+    if is_admin is not None:
         user.is_admin = is_admin
 
     logger.info(f'User {user} updated')
